package md

import (
	"code.fnuoos.com/EggPlanet/egg_models.git/src/model"
	"time"
)

type UserManagementGetUserListReq struct {
	ID               int64  `json:"id"` // 会员 ID
	Nickname         string `json:"nickname" example:"会员昵称"`
	RecommendID      int64  `json:"recommend_id"` // 推荐人 ID
	Tag              int    `json:"tag"`          // 标签 id
	Phone            string `json:"phone" example:"会员手机号"`
	InviteCode       string `json:"invite_code" example:"会员邀请码"`
	ParentInviteCode string `json:"parent_invite_code" example:"上级邀请码"`
	ParentPhone      string `json:"parent_phone" example:"上级手机号"`
	Sex              int    `json:"sex"` // 性别
	UnionId          string `json:"union_id" example:"微信号"`
	Level            int    `json:"level"`           // 会员等级
	RegisterType     int    `json:"register_type"`   // 注册类型(0.未知, 1.免验证码手机号注册，2.微信授权)
	State            int    `json:"state"`           // 状态
	Effective        int    `json:"effective"`       // 有效会员
	IsRealName       int    `json:"is_real_name"`    // 是否实名 0.未实名,1.已实名
	Memo             string `json:"memo"`            // 备注
	RegisterBefore   string `json:"register_before"` // 注册时间起点
	RegisterAfter    string `json:"register_after"`  // 注册时间终点
	LoginBefore      string `json:"login_before"`    // 最近登录开始时间
	LoginAfter       string `json:"login_after"`     // 最近登录结束时间
	Page             int    `json:"page"`
	Limit            int    `json:"limit"`
}

type Paginate struct {
	Limit int   `json:"limit"` // 每页大小
	Page  int   `json:"page"`  // 页数
	Total int64 `json:"total"` // 总数据量
}

type UserManagementGetUserListNode struct {
	ID               int64     `json:"id"`           // 会员 ID
	Tag              string    `json:"tag_name"`     // 会员标签
	Avatar           string    `json:"avatar"`       // 头像
	Nickname         string    `json:"nickname"`     // 昵称
	Phone            string    `json:"phone"`        // 手机号
	IsRealName       int       `json:"is_real_name"` // 是否实名 0.未实名,1.已实名
	Level            string    `json:"level_name"`   // 会员等级
	InviteCode       string    `json:"invite_code" example:"会员邀请码"`
	ParentID         int64     `json:"parent_id"` // 推荐人 ID
	ParentInviteCode string    `json:"parent_invite_code" example:"推荐人邀请码"`
	ParentPhone      string    `json:"parent_phone" example:"推荐人手机号"`
	RegisterTime     time.Time `json:"register_time"` // 注册时间
	Memo             string    `json:"memo"`          // 备注
	model.User
}

type UserManagementGetUserListResp struct {
	LevelsList []map[string]interface{}        `json:"levels_list"` // 等级列表
	TagsList   []map[string]interface{}        `json:"tags_list"`   // 标签列表
	List       []UserManagementGetUserListNode `json:"list"`
	Paginate   Paginate                        `json:"paginate"` // 分页信息
}

type UserInfo struct {
	model.User             `xorm:"extends"`
	TagID                  int    `xorm:"tag_id"`
	ParentPhone            string `xorm:"parent_phone"`
	ParentSystemInviteCode string `xorm:"parent_system_invite_code"`
	ParentCustomInviteCode string `xorm:"parent_custom_invite_code"`
}

type LevelCount struct {
	Level int `xorm:"level"`
	Count int `xorm:"count"`
}

type UserManagementUpdateUserInfoReq struct {
	UID         int64  `json:"uid,required"`
	Memo        string `json:"memo" example:"备注"`
	Disable     bool   `json:"disable"`       // 是否禁用用户
	Tag         int    `json:"tag"`           // 用户标签 ID
	LastLoginIp string `json:"last_login_ip"` // 用户最后登录 IP
	Avatar      string `json:"avatar"`        // 头像
}

type BasicInfoNode struct {
	Avatar           string `json:"avatar"`             // 头像
	Sex              int    `json:"sex"`                // 性别
	Nickname         string `json:"nickname"`           // 会员名称
	TagID            int    `json:"tag_id"`             // 标签 ID
	Phone            string `json:"phone"`              // 手机号
	UnionId          string `json:"union_id"`           // 微信号
	Password         string `json:"password"`           // 登录密码
	Passcode         string `json:"passcode"`           // 支付密码
	State            int    `json:"state"`              // 账号状态 1正常,2冻结
	Memo             string `json:"memo"`               // 备注
	ParentUid        int64  `json:"parent_uid"`         // 推荐人
	ParentName       string `json:"parent_name"`        // 推荐人名称
	ParentPhone      string `json:"parent_phone"`       // 推荐人手机号
	SystemInviteCode string `json:"system_invite_code"` // 系统邀请码
	CustomInviteCode string `json:"custom_invite_code"` // 自定义邀请码
	Level            string `json:"level"`              // 等级名称
}

type OtherNode struct {
	LastLoginIp  string    `json:"last_login_ip" ` // 最后登录 IP
	LastLoginAt  time.Time `json:"last_login_at" ` // 最近登录时间
	CreateAt     time.Time `json:"create_at" `     // 注册时间
	RegisterType int       `json:"register_at" `   // 注册类型(0.未知, 1.免验证码手机号注册，2.微信授权)
}

type WalletNode struct {
	Amount string `json:"amount"` // 用户余额
}

type VirtualAmountInfoNode struct {
	CoinName string `json:"coin_name"` // 货币类型
	Amount   string `json:"amount"`    // 余额
}

type UserManagementGetOneBasicResp struct {
	TagsList          []map[string]interface{} `json:"tags_list"`           // 标签列表
	LevelsList        []map[string]interface{} `json:"levels_list"`         // 等级列表
	CoinsList         []map[string]interface{} `json:"coins_list"`          // 货币列表
	VirtualAmountInfo []VirtualAmountInfoNode  `json:"virtual_amount_info"` // 虚拟资产钱包数据
	BasicInfo         BasicInfoNode            `json:"basic_info"`          // 基本信息
	WalletInfo        WalletNode               `json:"wallet_info"`         // 钱包信息
	OtherInfo         OtherNode                `json:"other_info"`          // 其他信息
}

type FansNode struct {
	ID          int64     `json:"id"` // 用户ID
	Nickname    string    `json:"nickname" example:"用户昵称"`
	Phone       string    `json:"phone" example:"手机号"`
	LevelTotal  int       `json:"level_total"`  // 所属代数
	Amount      string    `json:"amount"`       // 可提现余额
	TotalIncome string    `json:"total_income"` // 累计收益
	RegisterAt  time.Time `json:"register_at"`  // 注册时间
}

type UserManagementGetFansResp struct {
	List     []FansNode `json:"list"`     // 用户数据
	Paginate Paginate   `json:"paginate"` // 分页信息
}

type BalanceDetailNode struct {
	ID          int64  `json:"id"`           // 记录ID
	Uid         int64  `json:"uid"`          // 用户ID
	Nickname    string `json:"nickname"`     // 用户昵称
	Phone       string `json:"phone"`        // 用户手机号
	Amount      string `json:"amount"`       // 变更余额
	AfterAmount string `json:"after_amount"` // 变更后余额
	Kind        string `json:"kind"`         //类型 1:管理员操作增加余额 2:管理员操作扣除余额 3:蛋蛋能量兑换余额 4:余额兑换蛋蛋能量
	OrdID       string `json:"ord_Id"`       // 订单号
	CreateAt    string `json:"create_at"`    // 创建时间
}

type UserManagementGetBalanceDetailResp struct {
	List     []BalanceDetailNode `json:"list"`
	Paginate Paginate            `json:"paginate"`
}

type VirtualCoinDetailNode struct {
	Uid         int64  `json:"uid"`          // 用户 ID
	Amount      string `json:"amount"`       // 变更数量
	AfterAmount string `json:"after_amount"` // 变更后积分余额
	Direction   int    `json:"direction"`    // 类型 1.收入 2.支出
	CreateAt    string `json:"create_at"`    // 创建时间
}

type UserManagementGetVirtualCoinDetailResp struct {
	CoinList []map[string]interface{} `json:"coin_list"`
	List     []VirtualCoinDetailNode  `json:"list"`
	Paginate Paginate                 `json:"paginate"`
}
